@@ -2,9 +2,9 @@
 
 
 import json
+import os
 from importlib import import_module
-from pyclbr import Function
-from typing import Dict, Sequence
+from typing import Dict, Sequence, Callable,Union
 
 from .attribute import Attribute
 from .enum_attribute import EnumAttribute
@@ -31,12 +31,21 @@ class DMTReader():
             self.external_refs=external_refs
         self.datasource = None
 
-    def read(self, filename) -> Entity:
+    def read(self, filename) -> Union[Entity,Sequence[Entity]]:
         """ Read entity from file """
+        if self.__is_h5(filename):
+            # pylint: disable=import-outside-toplevel
+            from .h5.h5_reader import H5Reader
+            return H5Reader().read(filename)
+        #FIXME: Handle several root entities
         with open(filename, 'r',encoding="utf-8", errors='replace') as file:
             res=json.load(file)
             return self.from_dict(res)
 
+    def __is_h5(self,filename):
+        _, extension = os.path.splitext(filename)
+        extension = extension.lower()
+        return extension=='.h5' or extension=='.hdf5'
 
     def from_dict(self,ent_dict: Dict) -> Entity:
         """ Create entity from Dict """
@@ -84,7 +93,7 @@ class DMTReader():
 
         return entity_instance
 
-    def _resolve_type(self, atype: str) -> Function:
+    def _resolve_type(self, atype: str) -> Callable:
         pkg: any = None
         parts = atype.split("/")
         if self.datasource:
@@ -95,8 +104,8 @@ class DMTReader():
         package_path = ".".join(parts)
         try:
             pkg = import_module(package_path)
-        except ModuleNotFoundError:
-            raise Exception(f"Unable to load package {package_path}")
+        except ModuleNotFoundError as error:
+            raise Exception(f"Unable to load package {package_path}") from error
 
         constructor = pkg.__dict__.get(ename)
         return constructor
