@@ -3,6 +3,7 @@
 
 from enum import Enum
 import json
+import os
 from typing import Dict, Sequence
 import uuid
 from .attribute import Attribute
@@ -21,9 +22,19 @@ class DMTWriter:
 
     def write(self, entity: Entity, filename, indent=0):
         """Write entity to file"""
-        with open(filename, "w", encoding="utf-8") as file:
-            res = self.to_dict(entity)
-            json.dump(res, file, indent=indent)
+        if self.__is_h5(filename):
+            # pylint: disable=import-outside-toplevel
+            from .h5.h5_writer import H5Writer
+            H5Writer().write([entity], filename)
+        else:
+            with open(filename, "w", encoding="utf-8") as file:
+                res = self.to_dict(entity)
+                json.dump(res, file, indent=indent)
+
+    def __is_h5(self,filename):
+        _, extension = os.path.splitext(filename)
+        extension = extension.lower()
+        return extension=='.h5' or extension=='.hdf5'
 
     def to_dicts(self, entities: Sequence[Entity]) -> Sequence[Dict]:
         """Convert to DMT dictionaries"""
